
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

( cd usr/lib ; rm -rf libk3bdevice.so.6 )
( cd usr/lib ; ln -sf libk3bdevice.so.6.0.0 libk3bdevice.so.6 )
( cd usr/lib ; rm -rf libk3blib.so )
( cd usr/lib ; ln -sf libk3blib.so.6 libk3blib.so )
( cd usr/lib ; rm -rf libk3bdevice.so )
( cd usr/lib ; ln -sf libk3bdevice.so.6 libk3bdevice.so )
( cd usr/lib ; rm -rf libk3blib.so.6 )
( cd usr/lib ; ln -sf libk3blib.so.6.0.0 libk3blib.so.6 )
( cd usr/doc/HTML/en/k3b ; rm -rf common )
( cd usr/doc/HTML/en/k3b ; ln -sf /usr/share/doc/HTML/en/common common )
